#Returns a list with all RKEEL algorithm jars
getJarList <- function(){

  jarList <- list(
    #Main jar
    "RunKeel.jar",
    
    #Classification
    "Ensembles-I.jar", #AdaBoost.NC-C
    "ART.jar",
    "BNGE.jar",
    "Bojarczuk_GP.jar",
    "IS-BSE.jar",
    "C45_Binarization-C.jar",
    "C45.jar",
    "C45Rules.jar",
    "CamNN.jar",
    "Clas-CART.jar",
    "CenterNN.jar",
    "Clas-Fuzzy-CFAR.jar",
    "CFKNN.jar",
    "IS-CHC.jar",
    "IS-CNN.jar",
    "CPW.jar",
    "C_SVM.jar",
    "CW.jar",
    "RBFN_decremental_CL.jar",
    "Deeps.jar",
    "IG-DSM.jar",
    "DT_GA.jar",
    "Falco_GP.jar",
    "Clas-Fuzzy-FCRA.jar",
    "FRNN.jar",
    "FURIA-C.jar",
    "Clas-Fuzzy-FARCHD.jar",
    "FuzzyKNN.jar",
    "FuzzyNPC.jar",
    "Gann.jar",
    "ClassifierFuzzyAdaBoost.jar", #GFS-AdaBoost-C
    "ClassifierFuzzyLogitBoost.jar", #GFS-LogitBoost-C
    "ID3.jar",
    "IF_KNN.jar",
    "RBFN_incremental_CL.jar",
    "JFKNN.jar",
    "ClassifierKernel.jar",
    "KNN.jar",
    "KSNN.jar",
    "KStar.jar",
    "ClassifierADLinear.jar",
    "ClassifierLinearLMS.jar",
    "Logistic.jar",
    "Clas-MLP-BackProp.jar",
    "Naive_Bayes.jar",
    "NM.jar",
    "NNEP_Clas.jar",
    "NU_SVM.jar",
    "PART.jar",
    "PDFC.jar",
    "PFKNN.jar",
    "IG-PNN.jar",
    "ClassifierPolQuadraticLMS.jar",
    "Prism.jar",
    "PSO_ACO.jar",
    "PUBLIC.jar",
    "PW.jar",
    "ClassifierADQuadratic.jar",
    "RBFN_CL.jar",
    "Ripper.jar",
    "RISE.jar",
    "IS-SGA.jar",
    "IS-Shrink.jar",
    "Slipper.jar",
    "SMO.jar",
    "Tan_GP.jar",
    "VWFuzzyKNN.jar",

    #Regression
    "Regr-CART.jar",
    "EPSILON_SVR.jar",
    "ModelFSS98.jar", #FRSBM-R
    "crispSymRegGAP.jar", #GFS-GP-R
    "crispSymRegSAP.jar", #GFS-GSP-R
    "GFS_RB_MF.jar",
    "ModelLinearLMS.jar",
    "M5.jar",
    "M5Rules.jar",
    "Regr-MLP-BackProp.jar",
    "NU_SVR.jar",
    "ModelPolQuadraticLMS.jar",
    "RBFN.jar",
    "Thrift.jar",
    "Mam-WM.jar",

    #Preprocess
    "FS-ABB-IEP.jar",
    "IS-AllKNN.jar",
    "MV-AllPossible.jar",
    "Filter-ANR.jar",
    "Disc-Bayesian.jar",
    "CleanAttributes-TR.jar",
    "Disc-ClusterAnalysis.jar",
    "Trns-DecimalScaling.jar",
    "Disc-ID3.jar",
    "MV-Ignore.jar",
    "Filter-IterativePartitioningFilter.jar",
    "MV-KMeans.jar",
    "MV-KNN.jar",
    "FS-LVF-IEP.jar",
    "Trns-MinMax.jar",
    "IS-ModelCS.jar",
    "MV-MostCommon.jar",
    "Trns-Nominal2Binary.jar",
    "IS-POP.jar",
    "Disc-Proportional.jar",
    "IS-PSRCG.jar",
    "FS-Relief.jar",
    "Filter-SaturationFilter.jar",
    "FS-SFS-IEP.jar",
    "FS-SSGA-Integer-knn.jar",
    "Disc-UniformFrequency.jar",
    "Disc-UniformWidth.jar",
    "Trns-ZScore.jar",
	
	#Association rules
	"Alatasetal.jar",
	"Alcalaetal.jar",
	"Apriori.jar",
	"EARMGA.jar",
	"Eclat.jar",
	"FPgrowth.jar",
	"FuzzyApriori.jar",
	"GAR.jar",
	"GENAR.jar",
	"GeneticFuzzyApriori.jar",
	"GeneticFuzzyAprioriDC.jar",
	"KeelLateXTables.jar",
	"KeelToPMML.jar",
	"MODENAR.jar",
	"MOEA_Ghosh.jar",
	"MOPNAR.jar",
	"NICGAR.jar",
	"QAR_CIP_NSGAII.jar"

  )

  return(jarList)
}
